==> zio-aws-apigateway_2.13-5.17.155.1-sources.jar: zio/aws/apigateway/model/CreateBasePathMappingResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateBasePathMappingResponse(
    basePath: Option[String] = None,
    restApiId: Option[String] = None,
    stage: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse = {
    import CreateBasePathMappingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse
      .builder()
      .optionallyWith(basePath.map(value => value: java.lang.String))(
        _.basePath
      )
      .optionallyWith(restApiId.map(value => value: java.lang.String))(
        _.restApiId
      )
      .optionallyWith(stage.map(value => value: java.lang.String))(_.stage)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.CreateBasePathMappingResponse.ReadOnly =
    zio.aws.apigateway.model.CreateBasePathMappingResponse.wrap(buildAwsValue())
}
object CreateBasePathMappingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.CreateBasePathMappingResponse =
      zio.aws.apigateway.model.CreateBasePathMappingResponse(
        basePath.map(value => value),
        restApiId.map(value => value),
        stage.map(value => value)
      )
    def basePath: Option[String]
    def restApiId: Option[String]
    def stage: Option[String]
    def getBasePath: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("basePath", basePath)
    def getRestApiId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("restApiId", restApiId)
    def getStage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("stage", stage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse
  ) extends zio.aws.apigateway.model.CreateBasePathMappingResponse.ReadOnly {
    override val basePath: Option[String] =
      scala.Option(impl.basePath()).map(value => value: String)
    override val restApiId: Option[String] =
      scala.Option(impl.restApiId()).map(value => value: String)
    override val stage: Option[String] =
      scala.Option(impl.stage()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse
  ): zio.aws.apigateway.model.CreateBasePathMappingResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigateway_2.13-5.17.295.9-sources.jar: zio/aws/apigateway/model/CreateBasePathMappingResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateBasePathMappingResponse(
    basePath: Optional[String] = Optional.Absent,
    restApiId: Optional[String] = Optional.Absent,
    stage: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse = {
    import CreateBasePathMappingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse
      .builder()
      .optionallyWith(basePath.map(value => value: java.lang.String))(
        _.basePath
      )
      .optionallyWith(restApiId.map(value => value: java.lang.String))(
        _.restApiId
      )
      .optionallyWith(stage.map(value => value: java.lang.String))(_.stage)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.CreateBasePathMappingResponse.ReadOnly =
    zio.aws.apigateway.model.CreateBasePathMappingResponse.wrap(buildAwsValue())
}
object CreateBasePathMappingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.CreateBasePathMappingResponse =
      zio.aws.apigateway.model.CreateBasePathMappingResponse(
        basePath.map(value => value),
        restApiId.map(value => value),
        stage.map(value => value)
      )
    def basePath: Optional[String]
    def restApiId: Optional[String]
    def stage: Optional[String]
    def getBasePath: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("basePath", basePath)
    def getRestApiId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("restApiId", restApiId)
    def getStage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("stage", stage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse
  ) extends zio.aws.apigateway.model.CreateBasePathMappingResponse.ReadOnly {
    override val basePath: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.basePath())
      .map(value => value: String)
    override val restApiId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.restApiId())
      .map(value => value: String)
    override val stage: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.stage())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.CreateBasePathMappingResponse
  ): zio.aws.apigateway.model.CreateBasePathMappingResponse.ReadOnly =
    new Wrapper(impl)
}
